# -*- coding: utf-8 -*-


CATEGORY20 = [
    "#1f77b4",
    "#aec7e8",
    "#ff7f0e",
    "#ffbb78",
    "#2ca02c",
    "#98df8a",
    "#d62728",
    "#ff9896",
    "#9467bd",
    "#c5b0d5",
    "#8c564b",
    "#c49c94",
    "#e377c2",
    "#f7b6d2",
    "#7f7f7f",
    "#c7c7c7",
    "#bcbd22",
    "#dbdb8d",
    "#17becf",
    "#9edae5",
]

KIBANA_SEED_COLORS = [
    "#57c17b",
    "#6f87d8",
    "#663db8",
    "#bc52bc",
    "#9e3533",
    "#daa05d",
    "#00a69b",
]

DEFAULT_WIDTH = 800
DEFAULT_PIE_WIDTH = 200
DEFAULT_HEIGHT = 200
DEFAULT_PADDING = 5
